==> maven_3.5.4.orig.tar.xz: maven-maven-3.5.4/maven-resolver-provider/src/test/java/org/apache/maven/repository/internal/MavenRepositorySystemUtilsTest.java <==
package org.apache.maven.repository.internal;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.eclipse.aether.RepositorySystem;
import org.eclipse.aether.impl.MetadataGeneratorFactory;
import org.eclipse.aether.spi.locator.ServiceLocator;

import junit.framework.TestCase;

public class MavenRepositorySystemUtilsTest
    extends TestCase
{

    public void testGetRepositorySystem()
    {
        ServiceLocator locator = MavenRepositorySystemUtils.newServiceLocator();
        RepositorySystem repoSys = locator.getService( RepositorySystem.class );
        assertNotNull( repoSys );
    }

    public void testGetMetadataGeneratorFactories()
    {
        ServiceLocator locator = MavenRepositorySystemUtils.newServiceLocator();
        assertEquals( 2, locator.getServices( MetadataGeneratorFactory.class ).size() );
    }

}

==> maven_3.9.9.orig.tar.xz: maven-maven-3.9.9/maven-resolver-provider/src/test/java/org/apache/maven/repository/internal/MavenRepositorySystemUtilsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.repository.internal;

import junit.framework.TestCase;
import org.eclipse.aether.RepositorySystem;
import org.eclipse.aether.impl.MetadataGeneratorFactory;
import org.eclipse.aether.spi.locator.ServiceLocator;

public class MavenRepositorySystemUtilsTest extends TestCase {

    public void testGetRepositorySystem() {
        ServiceLocator locator = MavenRepositorySystemUtils.newServiceLocator();
        RepositorySystem repoSys = locator.getService(RepositorySystem.class);
        assertNotNull(repoSys);
    }

    public void testGetMetadataGeneratorFactories() {
        ServiceLocator locator = MavenRepositorySystemUtils.newServiceLocator();
        assertEquals(2, locator.getServices(MetadataGeneratorFactory.class).size());
    }
}
